xfconf-sys 0.2.0+dev

FFI bindings to libxfconf
xfconf-sys-0.2.0+dev has been yanked.

xfconf-sys

This crate provides FFI bindings for libxfconf, a library that can talk to Xfce's configuration system.

In general you will not need to use this crate, and will instead want to use xfconf instead.